@@ -7,6 +7,8 @@ https://github.com/zabuldon/teslajsonpy
 import logging
 from typing import Dict, Text
 
+from teslajsonpy.const import TESLA_DEFAULT_ENERGY_SITE_NAME
+
 _LOGGER = logging.getLogger(__name__)
 
 
@@ -34,7 +36,7 @@ class EnergySiteDevice:
         """
         self._id: int = data["id"]
         self._energy_site_id: int = data["energy_site_id"]
-        self._site_name: Text = data.get("site_name", f"{self._energy_site_id}")
+        self._site_name: Text = data.get("site_name", TESLA_DEFAULT_ENERGY_SITE_NAME)
         self._controller = controller
         self.should_poll: bool = True
         self.type: Text = "device"
@@ -45,7 +47,7 @@ class EnergySiteDevice:
         return f"{self._site_name} {self.type}"
 
     def _uniq_name(self) -> Text:
-        return self._name()
+        return f"{self._energy_site_id} {self.type}"
 
     def id(self) -> int:
         # pylint: disable=invalid-name
